---
name: Feature Request
about: Suggest a feature for lazy-text-classifiers
labels: enhancement
---

<!--
  ⚠️⚠️ Please do the following before submitting: ⚠️⚠️

  📖 Please read our Code of Conduct.
  🔎 Please search existing issues to avoid creating duplicates.
-->

### Feature Description

<!-- A clear and concise description of the feature you're requesting. -->

### Use Case

<!-- Please provide a use case to help us understand your request in context. -->

### Solution

<!-- Please describe your ideal solution. -->

### Alternatives

<!-- Please describe any alternatives you've considered, even if you've dismissed them. -->
